@@ -1,10 +1,12 @@
-static char    *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/RCS/battle.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";
+static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/RCS/battle.c,v 2.46 1997/04/18 12:06:12 zeus Exp zeus $";
 
 /*
  * $Log: battle.c,v $
- * Revision 2.44  1995/12/31  19:45:18  zeus
+ * Revision 2.46  1997/04/18 12:06:12  zeus
  * *** empty log message ***
  *
+ * Revision 2.45  1996/12/31  23:40:54  zeus
+ * Revision 2.44  1995/12/31  19:45:18  zeus
  * Revision 2.43  1995/03/20  01:43:09  zeus
  * Revision 2.42  1994/05/17  13:43:15  bampton
  * Revision 2.41  1994/04/08  03:11:28  bampton
@@ -13,29 +15,28 @@ static char    *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/RCS/battle.c,v 2
  * Revision 2.37  1993/09/07  20:50:32  bampton
  * Revision 2.33  1993/08/03  23:10:13  bampton
  * Revision 2.30  1993/07/14  14:59:26  bampton
- * Full RCS version
  * Revision 0.0  1993/07/14  13:41:46  bampton RCS prototype.
  * 
  * 
  */
 
 #define NOTIMEB
-#include "protos/common.h"
-#include "protos/prototypes.h"
-#include "protos/battle.h"
-#include "protos/battle-g.h"
-#include "protos/misc-g.h"
+#include "common.h"
+#include "prototypes.h"
+#include "battle.h"
+#include "battle-g.h"
+#include "misc-g.h"
 
 void battle_rcsid (void);
 
-extern player  *players;
-extern planet  *planets;
-extern sorted  *sorted_planets;
+extern player *players;
+extern planet *planets;
+extern sorted *sorted_planets;
 extern shiptype *shiptypes;
-extern battle  *battles;
+extern battle *battles;
 extern bombing *bombings;
-extern double   galaxysize;
-extern char     buf[256], buf2[256];
+extern double galaxysize;
+extern char buf[], buf2[];
 extern planetdefense *defender;
 
 #define INVOLVED -2.0
@@ -43,23 +44,23 @@ extern planetdefense *defender;
 void
 battle_rcsid (void)
 {
-  printf ("%s\n",rcsid);
+  printf ("%s\n", rcsid);
 }
 
 
 int
 atwar (player * P1, player * P2, planet * p)
 {
-  alliance       *a;
-  defensive      *d;
+  alliance *a;
+  defensive *d;
 
-  planetdefense  *pd;
+  planetdefense *pd;
 
-  if (P1 == P2) /* Speed mod */
+  if (P1 == P2)                 /* Speed mod */
     return PEACE;
 
   for (pd = defender; pd; pd = pd->next)
-    if ((pd->planet == p) && (pd->defender == P2) && (p->owner==P1))
+    if ((pd->planet == p) && (pd->defender == P2) && (p->owner == P1))
       return pd->dipstat;
 
   for (a = P1->allies; a; a = a->next)
@@ -74,7 +75,7 @@ atwar (player * P1, player * P2, planet * p)
 int
 cankill (group * attack, group * target)
 {
-  double          defense, ratio, size;
+  double defense, ratio, size;
 
   if (!attack->type->nguns)
     return 0;
@@ -85,14 +86,12 @@ cankill (group * attack, group * target)
   ratio = defense / (attack->tech.guns * attack->type->guns);
 
   return (ratio < 4.0);
-  /* ratio = attack->tech.guns * attack->type->guns / defense;
-  return ratio > .251; */
 }
 
 int
 kill (group * attack, group * target)
 {
-  double          defense, randomn, ratio, size;
+  double defense, randomn, ratio, size;
 
   size = shipmass (target);
   defense = shield_str (target->type->shields, target->tech.shields, size);
@@ -106,21 +105,20 @@ kill (group * attack, group * target)
 void
 fightphase (void)
 {
-  planet         *p;
-  player         *P, *P2;
-  group          *g; 
+  planet *p;
+  player *P, *P2;
+  group *g;
   group *g2;
-  int             i, j, ngroups, nships, nshipstofire, agroup, tgroup, shipno,
-                  involved;
-  int             moretargets, foundtarget, notfirstround;
-  int            *shipstofire;
-  group          *g3;
-  group         **fightgroups;
-  player        **groupplayers;
-  battle         *B;
-  shot           *S;
-  viewer         *V;
-  participant    *PA=NULL; /* To shut up lint */
+  int i, j, ngroups, nships, nshipstofire, agroup, tgroup, shipno, involved;
+  int moretargets, foundtarget, notfirstround;
+  int *shipstofire;
+  group *g3;
+  group **fightgroups;
+  player **groupplayers;
+  battle *B;
+  shot *S;
+  viewer *V;
+  participant *PA = NULL;       /* To shut up lint */
 
   for (p = planets; p; p = p->next)
   {
@@ -136,7 +134,7 @@ fightphase (void)
               if (g3->where == p && g3->dist == 0.0 &&
                   ((g->type->nguns && atwar (P, P2, p)) ||
                    (g3->type->nguns && atwar (P2, P, p))))
-              {                 /* REPLACE LINES HERE IF NOT FIXED */
+              { 
                 involved = 1;
                 break;
               }
@@ -171,6 +169,7 @@ fightphase (void)
     {
       fightgroups = alloc (ngroups * sizeof (group *));
       shipstofire = alloc (ngroups * sizeof (int));
+
       groupplayers = alloc (ngroups * sizeof (player *));
       i = 0;
       for (P = players; P; P = P->next)
@@ -219,7 +218,7 @@ fightphase (void)
       B->viewers = 0;
       B->participants = 0;
       for (P = players; P; P = P->next)
-        if (canseeplanet (P, p))
+        if (canseeplanet (P, p, 0))
         {
           V = alloc (sizeof (viewer));
           V->who = P;
@@ -241,10 +240,8 @@ fightphase (void)
             }
             g2 = alloc (sizeof (group));
             memcpy (g2, g, sizeof (group));
-#ifdef V3
             g2->left = g->ships;
             g2->alias = g;
-#endif
             addlist (&PA->groups, g2);
           }
       }
@@ -381,21 +378,20 @@ fightphase (void)
                   }
             }
         notfirstround = 1;
-      } while (moretargets);    /* while loop: keep fighting while targets */
+      }
+      while (moretargets);      /* while loop: keep fighting while targets */
 
       free (groupplayers);
       free (shipstofire);
       free (fightgroups);
       printf ("\n");
 
-#ifdef V3
       /* Collect information on number of survivors */
 
       for (PA = B->participants; PA; PA = PA->next)
         for (g = PA->groups; g; g = g->next)
-        
+
           g->left = g->alias->ships;
-#endif
     }
   }
 }
@@ -403,11 +399,11 @@ fightphase (void)
 void
 bombphase (void)
 {
-  player         *P, *P2;
-  group          *g;
-  planet         *p;
-  bombing        *b;
-  viewer         *V;
+  player *P, *P2;
+  group *g;
+  planet *p;
+  bombing *b;
+  viewer *V;
 
   for (P = players; P; P = P->next)
     for (g = P->groups; g; g = g->next)
@@ -427,7 +423,7 @@ bombphase (void)
         b->cap = p->cap;
         b->mat = p->mat;
         for (P2 = players; P2; P2 = P2->next)
-          if (canseeplanet (P2, p))
+          if (canseeplanet (P2, p, 0))
           {
             V = alloc (sizeof (viewer));
             V->who = P2;
@@ -435,9 +431,10 @@ bombphase (void)
           }
         addlist (&bombings, b);
         sterilize (p);
+
 #ifdef VERBOSE
-        printf ("Planet %s nuked by %s was %s\n",p->num,b->who->name,
-          b->whoose->name);
+        printf ("Planet %s nuked by %s was %s\n", p->num, b->who->name,
+                b->whoose->name);
 #endif
       }
     }
