@@ -1,11 +1,12 @@
-static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.45/cmds/RCS/Cmds-lib.c,v 2.45 1996/12/31 23:53:07 zeus Exp zeus $";
+static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/cmds/RCS/Cmds-lib.c,v 2.46 1997/04/18 12:13:56 zeus Exp zeus $";
 
 /*
 
  * $Log: Cmds-lib.c,v $
- * Revision 2.45  1996/12/31  23:53:07  zeus
+ * Revision 2.46  1997/04/18 12:13:56  zeus
  * *** empty log message ***
  *
+ * Revision 2.45  1996/12/31  23:53:07  zeus
  * Revision 2.44  1995/12/31  19:45:18  zeus
  * Revision 2.43  1995/03/20  01:43:09  zeus
  *
@@ -28,13 +29,13 @@ extern fleetname *fleets;
 extern player *players;
 extern planet *planets;
 
-char tbuf[100];
+char tbuf[MAXSTRLEN];
 int pos = 0;
 int comment = 0;
 int null_planet_ok;             /* Used to differentiate between missing 
 
                                    planet name, and optional one. */
-char err_tmp[80];
+char err_tmp[MAXSTRLEN * 2];
 static char *productionname[] =
 {
   "cap",
@@ -72,7 +73,8 @@ hstrcpy (char *a, const char *b)
   a[x] = b[x];
 }
 
-/* strcpy, that sets a to NULL if it is a comment. */
+/* strcpy, that sets a to NULL if it is a comment, and removes any
+   trailing comment characters/contents. */
 void
 hcstrcpy (char *a, const char *b)
 {
@@ -82,7 +84,8 @@ hcstrcpy (char *a, const char *b)
   if (b == NULL)
     return;
   if ((b[0] == ';') || (b[0] == '#'))
-  {                             /* b is a comment in its entirety, so toss back NULL for a */
+  {
+    /* b is a comment in its entirety, so toss back NULL for a */
     return;
   }
   a[0] = b[0];
@@ -90,8 +93,14 @@ hcstrcpy (char *a, const char *b)
   {
     for (x = 1; b[x]; x++)
     {
+      if (x == MAXSTRLEN)
+      {                         /* Prevent string length overrun */
+        a[MAXSTRLEN - 1] = '\0';
+        return;
+      }
+      /* Comment char preceeded by whitespace, so puke and return */
       if (((b[x] == ';') || (b[x] == '#')) && ((b[x - 1] == ' ') || (b[x - 1] == '\t')))
-      {                         /* Comment char preceeded by whitespace, so puke and return */
+      {
         a[x] = '\0';
         return;
       }
@@ -177,8 +186,9 @@ next_token (void)
     {
       for (tbuf[pos] = ' ', pos2 = pos + 1;; pos2++)
       {
+        /* Bugish Should distinguish btw bad quote and empty */
         if (tbuf[pos] == '\0')
-          return (NULL);        /* Bugish Should distinguish btw bad quote and empty */
+          return (NULL);
         if (tbuf[pos2] == '"')
         {
           tbuf[pos2] = ' ';
@@ -213,7 +223,7 @@ next_token (void)
 void
 extra_token (void)
 {
-  char t[100];
+  char t[MAXTEXT];
   char *x;
 
   if (comment)
@@ -226,7 +236,7 @@ extra_token (void)
   x = next_token ();
   if (x == NULL)
     return;
-  strcpy (t, x);
+  strncpy (t, x, MAXTEXT);
   if ((t[0] == ';') || (t[0] == '#'))
     return;
   sprintf (err_tmp, "Warning!!! Extra token '%s' ignored\n", t);
@@ -370,7 +380,6 @@ ninputcargotype (void)
     sprintf (err_tmp, "No cargo type specified!\n");
     return NOCARGO;
   }
-/*  cmd[3] = 0; */
   for (i = 0; i < sizeof (cargonames) / sizeof (char *); i++)
 
     if (!hstricmp (cargonames[i], cmd))
@@ -400,7 +409,6 @@ ninputcargotype2 (void)
     sprintf (err_tmp, "No cargo type specified!\n");
     return NOCARGO;
   }
-  /*cmd[3] = 0; */
   for (i = 0; i < sizeof (cargonames) / sizeof (char *); i++)
 
     if (!hstricmp (cargonames[i], cmd))
@@ -593,7 +601,6 @@ matchgroup (player * P, char *cmd)
   return g;
 }
 
-#ifdef UPGRADE
 fleetname *
 matchfleet (player * P, char *cmd)
 {
@@ -633,7 +640,6 @@ matchtype (player * P, char *cmd)
   sprintf (err_tmp, "There is no shiptype \"%s\".\n", cmd);
   return (NULL);
 }
-#endif
 
 planet *
 ninputplanet (void)
@@ -748,48 +754,13 @@ new_group (player * P, group * g, const int num)
   return (g2);
 }
 
-/* Illegal names:
-   -,_, ^#, ^;
- */
-int
-legal_name (const char *name, int flags)
-{
-  int x;
 
-  assert (name[0]);
-  if ((name[0] == '#') || (name[0] == ';'))
-  {
-    sprintf (err_tmp, "Illegal name: \"%s\"\n", name);
-    return (COMMENTNAME);
-  }
-  if (((name[0] == '-') || (name[0] == '_')) && (strlen (name) == 1))
-  {
-    sprintf (err_tmp, "Illegal name: \"%s\"\n", name);
-    return (DASHNAME);
-  }
-  if (flags & EMPIRE)
-  {
-    /* Only care if empire name about these chars... */
-    for (x = 0; name[x]; x++)
-    {
-      switch (name[x])
-      case '`':
-      case '\'':
-      case '"':
-      case '>':
-      case '<':
-      case '?':
-      case '!':
-      case '&':
-      case '*':
-      case '|':
-      case ':':
-      case '\\':
-      case '%':
-        sprintf (err_tmp, "Illegal name: \"%s\" because of %c\n", name, name[x]);
-      return (ILLEGNAME);
-      break;
-    }
-  }
-  return (0);
+/* Do all the initialziation that has to be done with each new order-
+   i.e. copy entire command string to tbuf, and toss first token. */
+void
+cmd_init (char *buf)
+{
+  hcstrcpy (tbuf, buf);
+  pos = 0;
+  (void) next_token ();         /* We've already know what this token is */
 }
