@@ -1,20 +1,21 @@
-static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/cmds/RCS/k.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";
+static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/cmds/RCS/k.c,v 2.46 1997/04/18 12:13:56 zeus Exp zeus $";
 
 /*
  *
  * $Log: k.c,v $
- * Revision 2.44  1995/12/31  19:45:18  zeus
+ * Revision 2.46  1997/04/18 12:13:56  zeus
  * *** empty log message ***
  *
+ * Revision 2.44  1995/12/31  19:45:18  zeus
  * Revision 2.43  1995/03/20  01:43:09  zeus
  *
- *
  */
 
 #define NOTIMEB
  
+#include "common.h"
+
 void k_cmd_rcsid (void);
-#include "../protos/common.h"
 
 void
 k_cmd_rcsid (void)
@@ -23,13 +24,11 @@ k_cmd_rcsid (void)
 }
 
 #ifdef KCMD
-#include "../protos/prototypes.h"
-#include "../protos/cmds.h"
-#include "../protos/cmds-g.h"
-#include "../protos/enterturn-g.h"
+#include "prototypes.h"
+#include "cmds.h"
+#include "cmds-g.h"
+#include "enterturn-g.h"
 
-extern char tbuf[];
-extern int pos;
 extern int null_planet_ok;
 extern player *players;
 extern planetdefense *defender;
@@ -45,11 +44,9 @@ k_cmd (char *buf, player * P)
   planetdefense *pd, *pd2;
   int comment;
 
-  hcstrcpy (tbuf, buf);
-  comment=pos = 0;
-  (void) next_token ();
-
+  cmd_init(buf);
   null_planet_ok = DASH;
+  comment=0;
   p = ninputplanet ();
   if (p)
   {
