@@ -1,7 +1,10 @@
 /*
- * $Header: /silver/homes/zeus/Blind-2.44/protos/RCS/version.h,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $
+ * $Header: /plaid/homes/zeus/Blind-2.46/protos/RCS/version.h,v 2.45 1997/01/01 00:15:27 zeus Exp $
  *
  * $Log: version.h,v $
+ * Revision 2.45  1997/01/01  00:15:27  zeus
+ * *** empty log message ***
+ *
  * Revision 2.44  1995/12/31  19:45:18  zeus
  * *** empty log message ***
  *
@@ -54,3 +57,11 @@ void u_cmd_rcsid(void);
 void v_cmd_rcsid(void);
 void w_cmd_rcsid(void);
 void x_cmd_rcsid(void);
+void y_cmd_rcsid(void);
+void report_status_rcsid(void);
+void report_ships_rcsid(void);
+void report_planets_rcsid(void);
+void report_map_rcsid(void);
+void report_gm_rcsid(void);
+void report_main_rcsid(void);
+void report_battle_rcsid(void);
